@@ -8,12 +8,12 @@ from PyQt4 import QtCore, QtGui, QtMaemo5
 import sys
 import os
 import locale
-import pexpect
 import threading
 from graph import Graph
 import calendar
 from datetime import datetime,timedelta
 from time import mktime
+from sqlite3 import dbapi2 as sqlite
 DB_FILE="/home/user/.rtcom-eventlogger/el-v1.db"
 EVT_SMS="""RTCOM_EL_EVENTTYPE_SMS_MESSAGE"""
 EVT_CALL="""RTCOM_EL_EVENTTYPE_CALL"""
@@ -24,9 +24,13 @@ CONFIG_FILE=CONFIG_DIR+"/options.cfg"
 
 def getSQL(sqlstr):
     #print sqlstr
-    sql=pexpect.spawn("sqlite3",[DB_FILE,sqlstr])
-    res=sql.readline()
-    sql.sendeof()
+    #sql=pexpect.spawn("sqlite3",[DB_FILE,sqlstr])
+    #res=sql.readline()
+    #sql.sendeof()
+    conn = sqlite.connect(DB_FILE)
+    res=conn.execute(sqlstr)
+    res=res.fetchone()[0]
+    conn.close()
     return res
 
 def getEventType(evt_type):
@@ -154,7 +158,7 @@ class About(object):
 "p, li { white-space: pre-wrap; }\n"
 "</style></head><body style=\" font-family:\'Ubuntu\'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
 "<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:16pt; font-weight:600;\">SMS Counter</span></p>\n"
-"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt; font-weight:600;\">v0.3</span></p>\n"
+"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt; font-weight:600;\">v0.4</span></p>\n"
 "<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt; font-weight:600;\"></p>\n"
 "<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><img src=\"/usr/share/icons/hicolor/64x64/hildon/smscounter.png\" /></p>\n"
 "<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt; font-weight:600;\"></p>\n"
@@ -617,9 +621,11 @@ class Main(QtGui.QWidget):
         QtGui.QWidget.__init__(self, parent)
         self.mw=MainWidget()
         self.mw.setupUi(self)
-if __name__ == "__main__":
+def main():
     locale.setlocale(locale.LC_ALL, '')
     app = QtGui.QApplication(sys.argv)
     qb = Main()
     qb.show()
     sys.exit(app.exec_())
+if __name__ == "__main__":
+    main()
